@@ -1,10 +1,11 @@
-﻿define(['jQuery'], function ($) {
+﻿define(['browser'], function (browser) {
 
     var supportsTextTracks;
     var hlsPlayer;
     var requiresSettingStartTimeOnStart;
     var subtitleTrackIndexToSetOnPlaying;
     var currentTrackList;
+    var currentPlayOptions;
 
     function htmlMediaRenderer(options) {
 
@@ -12,7 +13,7 @@
         var self = this;
 
         function onEnded() {
-            destroyCustomTrack();
+            destroyCustomTrack(this);
             Events.trigger(self, 'ended');
         }
 
@@ -32,6 +33,13 @@
             //        }
             //    }
             //}
+
+            if (options.type == 'video') {
+                // Get the player position + the transcoding offset
+                var timeMs = this.currentTime * 1000;
+                timeMs += ((currentPlayOptions.startTimeTicksOffset || 0) / 10000);
+                updateSubtitleText(timeMs);
+            }
             Events.trigger(self, 'timeupdate');
         }
 
@@ -43,7 +51,7 @@
 
             var elem = e.target;
             elem.removeEventListener('playing', onOneAudioPlaying);
-            $('.mediaPlayerAudioContainer').hide();
+            document.querySelector('.mediaPlayerAudioContainer').classList.add('hide');
         }
 
         function onPlaying() {
@@ -68,7 +76,7 @@
 
         function onError(e) {
 
-            destroyCustomTrack();
+            destroyCustomTrack(this);
 
             var elem = e.target;
             var errorCode = elem.error ? elem.error.code : '';
@@ -95,25 +103,6 @@
             });
         }
 
-        function getStartTime(url) {
-
-            var src = url;
-
-            var parts = src.split('#');
-
-            if (parts.length > 1) {
-
-                parts = parts[parts.length - 1].split('=');
-
-                if (parts.length == 2) {
-
-                    return parseFloat(parts[1]);
-                }
-            }
-
-            return 0;
-        }
-
         function onOneVideoPlaying(e) {
 
             var element = e.target;
@@ -124,18 +113,17 @@
             var requiresNativeControls = !self.enableCustomVideoControls();
 
             if (requiresNativeControls) {
-                $(element).attr('controls', 'controls');
+                element.setAttribute('controls', 'controls');
             }
 
             if (requiresSettingStartTimeOnStart) {
-                var src = (self.currentSrc() || '').toLowerCase();
 
-                var startPositionInSeekParam = getStartTime(src);
+                var startPositionInSeekParam = currentPlayOptions.startPositionInSeekParam;
 
                 // Appending #t=xxx to the query string doesn't seem to work with HLS
-                if (startPositionInSeekParam && src.indexOf('.m3u8') != -1) {
+                if (startPositionInSeekParam && currentSrc.indexOf('.m3u8') != -1) {
 
-                    var delay = browserInfo.safari ? 2500 : 0;
+                    var delay = browser.safari ? 2500 : 0;
                     if (delay) {
                         setTimeout(function () {
                             element.currentTime = startPositionInSeekParam;
@@ -149,9 +137,9 @@
 
         function createAudioElement() {
 
-            var elem = $('.mediaPlayerAudio');
+            var elem = document.querySelector('.mediaPlayerAudio');
 
-            if (!elem.length) {
+            if (!elem) {
                 var html = '';
 
                 var requiresControls = !MediaPlayer.canAutoPlayAudio();
@@ -159,19 +147,17 @@
                 if (requiresControls) {
                     html += '<div class="mediaPlayerAudioContainer" style="position: fixed;top: 40%;text-align: center;left: 0;right: 0;z-index:999999;"><div class="mediaPlayerAudioContainerInner">';;
                 } else {
-                    html += '<div class="mediaPlayerAudioContainer" style="display:none;padding: 1em;background: #222;"><div class="mediaPlayerAudioContainerInner">';;
+                    html += '<div class="mediaPlayerAudioContainer hide" style="padding: 1em;background: #222;"><div class="mediaPlayerAudioContainerInner">';;
                 }
 
                 html += '<audio class="mediaPlayerAudio" controls>';
                 html += '</audio></div></div>';
 
-                $(document.body).append(html);
+                document.body.insertAdjacentHTML('beforeend', html);
 
-                elem = $('.mediaPlayerAudio');
+                elem = document.querySelector('.mediaPlayerAudio');
             }
 
-            elem = elem[0];
-
             elem.addEventListener('playing', onOneAudioPlaying);
             elem.addEventListener('timeupdate', onTimeUpdate);
             elem.addEventListener('ended', onEnded);
@@ -207,10 +193,10 @@
             var requiresNativeControls = !self.enableCustomVideoControls();
 
             // Safari often displays the poster under the video and it doesn't look good
-            var poster = !browserInfo.safari && options.poster ? (' poster="' + options.poster + '"') : '';
+            var poster = !browser.safari && options.poster ? (' poster="' + options.poster + '"') : '';
 
             // Can't autoplay in these browsers so we need to use the full controls
-            if (requiresNativeControls && AppInfo.isNativeApp && browserInfo.android) {
+            if (requiresNativeControls && AppInfo.isNativeApp && browser.android) {
                 html += '<video class="itemVideo" id="itemVideo" preload="metadata" autoplay="autoplay"' + poster + ' webkit-playsinline>';
             }
             else if (requiresNativeControls) {
@@ -224,9 +210,10 @@
 
             html += '</video>';
 
-            var elem = $('#videoElement', '#videoPlayer').prepend(html);
+            var elem = document.querySelector('#videoPlayer #videoElement');
+            elem.insertAdjacentHTML('afterbegin', html);
 
-            var itemVideo = $('.itemVideo', elem)[0];
+            var itemVideo = elem.querySelector('.itemVideo');
 
             itemVideo.addEventListener('loadedmetadata', onLoadedMetadata);
 
@@ -274,7 +261,7 @@
 
         self.stop = function () {
 
-            destroyCustomTrack();
+            destroyCustomTrack(mediaElement);
 
             if (mediaElement) {
                 mediaElement.pause();
@@ -325,32 +312,34 @@
 
             if (!elem) {
                 currentSrc = null;
+                currentPlayOptions = null;
                 return;
             }
 
+            currentPlayOptions = streamInfo;
+
             if (!streamInfo) {
                 currentSrc = null;
                 elem.src = null;
                 elem.src = "";
 
                 // When the browser regains focus it may start auto-playing the last video
-                if (browserInfo.safari) {
+                if (browser.safari) {
                     elem.src = 'files/dummy.mp4';
                     elem.play();
                 }
 
                 return;
             }
-
             elem.crossOrigin = getCrossOriginValue(mediaSource);
             var val = streamInfo.url;
 
-            if (AppInfo.isNativeApp && browserInfo.safari) {
+            if (AppInfo.isNativeApp && browser.safari) {
                 val = val.replace('file://', '');
             }
 
             requiresSettingStartTimeOnStart = false;
-            var startTime = getStartTime(val);
+            var startTime = streamInfo.startPositionInSeekParam;
             var playNow = false;
 
             if (elem.tagName.toLowerCase() == 'audio') {
@@ -495,7 +484,9 @@
                 }
 
                 if (elem.tagName.toLowerCase() != 'audio') {
-                    $(elem).remove();
+                    if (elem.parentNode) {
+                        elem.parentNode.removeChild(elem);
+                    }
                 }
             }
         };
@@ -512,25 +503,41 @@
 
         function enableNativeTrackSupport(track) {
 
-            if (browserInfo.safari && browserInfo.mobile) {
+            if (browser.safari && browser.mobile) {
                 // Leave it to apple to have different behavior between safari on ios vs osx
                 return false;
             }
 
-            if (browserInfo.firefox) {
+            if (browser.firefox) {
                 if ((currentSrc || '').toLowerCase().indexOf('.m3u8') != -1) {
                     return false;
                 }
             }
 
+            if (track) {
+                var format = (track.format || '').toLowerCase();
+                if (format == 'ssa' || format == 'ass') {
+                    // libjass is needed here
+                    return false;
+                }
+            }
+
             return true;
         }
 
-        function destroyCustomTrack(isPlaying) {
+        function destroyCustomTrack(videoElement, isPlaying) {
+
+            window.removeEventListener('resize', onVideoResize);
+            window.removeEventListener('orientationchange', onVideoResize);
+
+            var videoSubtitlesElem = document.querySelector('.videoSubtitles');
+            if (videoSubtitlesElem) {
+                videoSubtitlesElem.parentNode.removeChild(videoSubtitlesElem);
+            }
 
             if (isPlaying) {
 
-                var allTracks = mediaElement.textTracks; // get list of tracks
+                var allTracks = videoElement.textTracks; // get list of tracks
                 for (var i = 0; i < allTracks.length; i++) {
 
                     var currentTrack = allTracks[i];
@@ -542,6 +549,15 @@
             }
 
             customTrackIndex = -1;
+            currentSubtitlesElement = null;
+            currentTrackEvents = null;
+            currentClock = null;
+
+            var renderer = currentAssRenderer;
+            if (renderer) {
+                renderer.setEnabled(false);
+            }
+            currentAssRenderer = null;
         }
 
         function fetchSubtitles(track) {
@@ -553,12 +569,10 @@
             });
         }
 
-        var customTrackIndex = -1;
-
-        function setTrackForCustomDisplay(track) {
+        function setTrackForCustomDisplay(videoElement, track) {
 
             if (!track) {
-                destroyCustomTrack(true);
+                destroyCustomTrack(videoElement, true);
                 return;
             }
 
@@ -567,17 +581,67 @@
                 return;
             }
 
-            destroyCustomTrack(true);
+            destroyCustomTrack(videoElement, true);
             customTrackIndex = track.index;
-            renderTracksEvents(track);
+            renderTracksEvents(videoElement, track);
+            lastCustomTrackMs = 0;
         }
 
-        function renderTracksEvents(track) {
+        function renderWithLibjass(videoElement, track) {
+
+            var rendererSettings = {};
+
+            require(['libjass'], function (libjass) {
+
+                libjass.ASS.fromUrl(track.url).then(function (ass) {
+
+                    var clock = currentClock = new libjass.renderers.ManualClock();
+
+                    // Create a DefaultRenderer using the video element and the ASS object
+                    var renderer = new libjass.renderers.WebRenderer(ass, clock, videoElement.parentNode.parentNode, rendererSettings);
+
+                    currentAssRenderer = renderer;
+
+                    renderer.addEventListener("ready", function () {
+                        try {
+                            renderer.resize(videoElement.offsetWidth, videoElement.offsetHeight, 0, 0);
+                            window.removeEventListener('resize', onVideoResize);
+                            window.addEventListener('resize', onVideoResize);
+                            window.removeEventListener('orientationchange', onVideoResize);
+                            window.addEventListener('orientationchange', onVideoResize);
+                            //clock.pause();
+                        }
+                        catch (ex) {
+                        }
+                    });
+                });
+            });
+        }
+
+        function onVideoResize() {
+            var renderer = currentAssRenderer;
+            if (renderer) {
+                var videoElement = mediaElement;
+                var width = videoElement.offsetWidth;
+                var height = videoElement.offsetHeight;
+                console.log('videoElement resized: ' + width + 'x' + height);
+                renderer.resize(width, height, 0, 0);
+            }
+        }
+
+        function renderTracksEvents(videoElement, track) {
+
+            var format = (track.format || '').toLowerCase();
+            if (format == 'ssa' || format == 'ass') {
+                // libjass is needed here
+                renderWithLibjass(videoElement, track);
+                return;
+            }
 
             var trackElement = null;
             var expectedId = 'manualTrack' + track.index;
 
-            var allTracks = mediaElement.textTracks; // get list of tracks
+            var allTracks = videoElement.textTracks; // get list of tracks
             for (var i = 0; i < allTracks.length; i++) {
 
                 var currentTrack = allTracks[i];
@@ -591,7 +655,7 @@
             }
 
             if (!trackElement) {
-                trackElement = mediaElement.addTextTrack('subtitles', 'manualTrack' + track.index, track.language || 'und');
+                trackElement = videoElement.addTextTrack('subtitles', 'manualTrack' + track.index, track.language || 'und');
                 trackElement.label = 'manualTrack' + track.index;
 
                 // download the track json
@@ -602,7 +666,7 @@
                     // add some cues to show the text
                     // in safari, the cues need to be added before setting the track mode to showing
                     data.TrackEvents.forEach(function (trackEvent) {
-                        trackElement.addCue(new VTTCue(trackEvent.StartPositionTicks / 10000000, trackEvent.EndPositionTicks / 10000000, trackEvent.Text.replace(/\\N/gi, '\n')));
+                        trackElement.addCue(new (window.VTTCue || window.TextTrackCue)(trackEvent.StartPositionTicks / 10000000, trackEvent.EndPositionTicks / 10000000, trackEvent.Text.replace(/\\N/gi, '\n')));
                     });
                     trackElement.mode = 'showing';
                 });
@@ -611,6 +675,58 @@
             }
         }
 
+        var currentSubtitlesElement;
+        var currentTrackEvents;
+        var customTrackIndex = -1;
+        var lastCustomTrackMs = 0;
+        var currentClock;
+        var currentAssRenderer;
+        function updateSubtitleText(timeMs) {
+
+            var clock = currentClock;
+            if (clock) {
+                clock.seek(timeMs / 1000);
+            }
+
+            var trackEvents = currentTrackEvents;
+            if (!trackEvents) {
+                return;
+            }
+
+            if (!currentSubtitlesElement) {
+                var videoSubtitlesElem = document.querySelector('.videoSubtitles');
+                if (!videoSubtitlesElem) {
+                    videoSubtitlesElem = document.createElement('div');
+                    videoSubtitlesElem.classList.add('videoSubtitles');
+                    videoSubtitlesElem.innerHTML = '<div class="videoSubtitlesInner"></div>';
+                    document.body.appendChild(videoSubtitlesElem);
+                }
+                currentSubtitlesElement = videoSubtitlesElem.querySelector('.videoSubtitlesInner');
+            }
+
+            if (lastCustomTrackMs > 0) {
+                if (Math.abs(lastCustomTrackMs - timeMs) < 500) {
+                    return;
+                }
+            }
+
+            lastCustomTrackMs = new Date().getTime();
+
+            var positionTicks = timeMs * 10000;
+            for (var i = 0, length = trackEvents.length; i < length; i++) {
+
+                var caption = trackEvents[i];
+                if (positionTicks >= caption.StartPositionTicks && positionTicks <= caption.EndPositionTicks) {
+                    currentSubtitlesElement.innerHTML = caption.Text;
+                    currentSubtitlesElement.classList.remove('hide');
+                    return;
+                }
+            }
+
+            currentSubtitlesElement.innerHTML = '';
+            currentSubtitlesElement.classList.add('hide');
+        }
+
         self.setCurrentTrackElement = function (streamIndex) {
 
             console.log('Setting new text track index to: ' + streamIndex);
@@ -621,9 +737,9 @@
 
             if (enableNativeTrackSupport(track)) {
 
-                setTrackForCustomDisplay(null);
+                setTrackForCustomDisplay(mediaElement, null);
             } else {
-                setTrackForCustomDisplay(track);
+                setTrackForCustomDisplay(mediaElement, track);
 
                 // null these out to disable the player's native display (handled below)
                 streamIndex = -1;
@@ -646,7 +762,7 @@
                 console.log('expectedId: ' + expectedId + '--currentTrack.Id:' + currentTrack.id);
 
                 // IE doesn't support track id
-                if (browserInfo.msie || browserInfo.edge) {
+                if (browser.msie || browser.edge) {
                     if (trackIndex == i) {
                         mode = 1; // show this track
                     } else {
@@ -683,6 +799,22 @@
             }
         };
 
+        function replaceQueryString(url, param, value) {
+            var re = new RegExp("([?|&])" + param + "=.*?(&|$)", "i");
+            if (url.match(re))
+                return url.replace(re, '$1' + param + "=" + value + '$2');
+            else if (value) {
+
+                if (url.indexOf('?') == -1) {
+                    return url + '?' + param + "=" + value;
+                }
+
+                return url + '&' + param + "=" + value;
+            }
+
+            return url;
+        }
+
         self.updateTextStreamUrls = function (startPositionTicks) {
 
             if (!self.supportsTextTracks()) {
@@ -690,8 +822,8 @@
             }
 
             var allTracks = mediaElement.textTracks; // get list of tracks
-
-            for (var i = 0; i < allTracks.length; i++) {
+            var i;
+            for (i = 0; i < allTracks.length; i++) {
 
                 var track = allTracks[i];
 
@@ -706,23 +838,25 @@
                 }
             }
 
-            $('track', mediaElement).each(function () {
+            var trackElements = mediaElement.querySelectorAll('track');
+            for (i = 0; i < trackElements.length; i++) {
 
-                this.src = replaceQueryString(this.src, 'startPositionTicks', startPositionTicks);
+                var trackElement = trackElements[i];
 
-            });
+                trackElement.src = replaceQueryString(trackElement.src, 'startPositionTicks', startPositionTicks);
+            }
         };
 
         self.enableCustomVideoControls = function () {
 
-            if (AppInfo.isNativeApp && browserInfo.safari) {
+            if (AppInfo.isNativeApp && browser.safari) {
 
-                if (navigator.userAgent.toLowerCase().indexOf('iphone') != -1) {
-                    return true;
+                if (navigator.userAgent.toLowerCase().indexOf('ipad') != -1) {
+                    // Need to disable it in order to support picture in picture
+                    return false;
                 }
 
-                // Need to disable it in order to support picture in picture
-                return false;
+                return true;
             }
 
             return self.canAutoPlayVideo();
@@ -734,7 +868,7 @@
                 return true;
             }
 
-            if (browserInfo.mobile) {
+            if (browser.mobile) {
                 return false;
             }
 
