@@ -1,11 +1,11 @@
-﻿define([], function () {
+﻿define(['components/categorysyncbuttons', 'components/groupedcards', 'cardBuilder'], function (categorysyncbuttons, groupedcards, cardBuilder) {
 
     function getView() {
 
         return 'Thumb';
     }
 
-    function loadLatest(context, params) {
+    function getLatestPromise(context, params) {
 
         Dashboard.showLoadingMsg();
 
@@ -17,27 +17,31 @@
 
             IncludeItemTypes: "Episode",
             Limit: 30,
-            Fields: "PrimaryImageAspectRatio,SyncInfo",
+            Fields: "PrimaryImageAspectRatio,BasicSyncInfo",
             ParentId: parentId,
             ImageTypeLimit: 1,
-            EnableImageTypes: "Primary,Backdrop,Banner,Thumb"
+            EnableImageTypes: "Primary,Backdrop,Thumb"
         };
 
-        ApiClient.getJSON(ApiClient.getUrl('Users/' + userId + '/Items/Latest', options)).then(function (items) {
+        return ApiClient.getJSON(ApiClient.getUrl('Users/' + userId + '/Items/Latest', options));
+    }
+
+    function loadLatest(context, params, promise) {
+
+        promise.then(function (items) {
 
             var view = getView();
             var html = '';
 
             if (view == 'ThumbCard') {
 
-                html += LibraryBrowser.getPosterViewHtml({
+                html += cardBuilder.getCardsHtml({
                     items: items,
                     shape: "backdrop",
                     preferThumb: true,
                     inheritThumb: false,
                     showUnplayedIndicator: false,
                     showChildCountIndicator: true,
-                    overlayText: false,
                     showParentTitle: true,
                     lazy: true,
                     showTitle: true,
@@ -46,7 +50,7 @@
 
             } else if (view == 'Thumb') {
 
-                html += LibraryBrowser.getPosterViewHtml({
+                html += cardBuilder.getCardsHtml({
                     items: items,
                     shape: "backdrop",
                     preferThumb: true,
@@ -54,7 +58,6 @@
                     showParentTitle: false,
                     showUnplayedIndicator: false,
                     showChildCountIndicator: true,
-                    overlayText: false,
                     centerText: true,
                     lazy: true,
                     showTitle: false,
@@ -74,9 +77,20 @@
 
         var self = this;
 
-        self.renderTab = function() {
+        categorysyncbuttons.init(tabContent);
 
-            loadLatest(tabContent, params);
+        var latestPromise;
+
+        self.preRender = function () {
+
+            latestPromise = getLatestPromise(view, params);
         };
+
+        self.renderTab = function () {
+
+            loadLatest(tabContent, params, latestPromise);
+        };
+
+        tabContent.querySelector('#latestEpisodes').addEventListener('click', groupedcards.onItemsContainerClick);
     };
 });
\ No newline at end of file
